@@ -1302,7 +1302,7 @@ def _solve_expression(f, x, explicit_solutions, multiplicities,
     # check if all variables are assumed integer;
     # if so, we have a Diophantine
 
-    def has_integer_assumption(v):
+    def has_integer_assumption(v) -> bool:
         from sage.symbolic.assumptions import assumptions, GenericDeclaration
         alist = assumptions()
         return any(isinstance(a, GenericDeclaration) and a.has(v) and
@@ -1700,7 +1700,7 @@ def _solve_mod_prime_power(eqns, p, m, vars):
             pairs = product(shifts, ans)
             possibles = (tuple(vector(t) + vector(shift) * (mrunning // p))
                          for shift, t in pairs)
-        ans = list(t for t in possibles if all(e(*t) == 0 for e in eqns_mod))
+        ans = [t for t in possibles if all(e(*t) == 0 for e in eqns_mod)]
         if not ans:
             return ans
 
@@ -1809,7 +1809,7 @@ def solve_ineq_fourier(ineq, vars=None):
     - Robert Marik (01-2010)
     """
     if vars is None:
-        setvars = set([])
+        setvars = set()
         for i in (ineq):
             setvars = setvars.union(set(i.variables()))
             vars = list(setvars)
